# greenpeace

![build](https://github.com/fdieulle/greenpeace/actions/workflows/build.yml/badge.svg)
[![codecov](https://codecov.io/gh/fdieulle/greenpeace/branch/main/graph/badge.svg?token=7AAFH9JUHG)](https://codecov.io/gh/fdieulle/greenpeace)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Python environment clean up
